Subject: [bug#30734] [PATCH core-updates 1/3] gnu: util-linux: Don't build 'nologin'.

From: Marius Bakke <[email-masked]>
Date: Tue, 6 Mar 2018 17:56:40 +0100

* gnu/packages/linux.scm (util-linux)[source](snippet): Add substitution.
---
 gnu/packages/linux.scm | 7 ++++---
 1 file changed, 4 insertions(+), 3 deletions(-)

diff --git a/gnu/packages/linux.scm b/gnu/packages/linux.scm
index c33b473ca..e63abcea4 100644
--- a/gnu/packages/linux.scm
+++ b/gnu/packages/linux.scm
@@ -559,12 +559,13 @@ providing the system administrator with some help in common tasks.")
               (patches (search-patches "util-linux-tests.patch"))
               (modules '((guix build utils)))
               (snippet
                ;; We take the 'logger' program from GNU Inetutils and 'kill'
                ;; from GNU Coreutils.
                '(begin
                   (substitute* "configure"
                     (("build_logger=yes") "build_logger=no")
-                    (("build_kill=yes") "build_kill=no"))
+                    (("build_kill=yes") "build_kill=no")
+                    (("build_nologin=yes") "build_nologin=no"))
                   #t))))
     (build-system gnu-build-system)
     (outputs '("out"
@@ -559,12 +559,13 @@ providing the system administrator with some help in common tasks.")
               (modules '((guix build utils)))
               (snippet
-               ;; We take the 'logger' program from GNU Inetutils and 'kill'
-               ;; from GNU Coreutils.
+               ;; We take 'nologin' from Shadow, the 'logger' program from
+               ;; GNU Inetutils and 'kill' from GNU Coreutils.
                '(begin
                   (substitute* "configure"
-- 
2.16.2